diff include/render.h @ 19:c98863e63174 matrix_gpio

Renamed matrixGpio to digital and matrix to analog
author Giulio Moro <giuliomoro@yahoo.it>
date Thu, 30 Apr 2015 16:58:41 +0100
parents 670be80463a3
children ad5cd8dd99b3
line wrap: on
line diff
--- a/include/render.h	Thu Apr 30 16:02:47 2015 +0100
+++ b/include/render.h	Thu Apr 30 16:58:41 2015 +0100
@@ -11,7 +11,7 @@
 // uint types
 #include <stdint.h>
 #include "../include/Utilities.h"
-#include "../include/matrix_gpio_mapping.h"
+#include "../include/digital_gpio_mapping.h"
 // Mappings from pin numbers on PCB to actual DAC channels
 // This gives the DAC and ADC connectors the same effective pinout
 #define DAC_PIN0	6
@@ -32,19 +32,19 @@
 #define ADC_PIN6	6
 #define ADC_PIN7	7
 
-#define MATRIX_MAX  65535.0
+#define ANALOG_MAX  65535.0
 
 extern int gNumAudioChannels;	// How many audio channels are present
-extern int gNumMatrixChannels;	// How many matrix channels are present
-extern int gNumMatrixGpioChannels;
-bool initialise_render(int numMatrixChannels, int numMatrixGpioChannels, int numAudioChannels,
-		  	   	   	   int numMatrixFramesPerPeriod,
+extern int gNumAnalogChannels;	// How many analog channels are present
+extern int gNumDigitalChannels;
+bool initialise_render(int numAnalogChannels, int numDigitalChannels, int numAudioChannels,
+		  	   	   	   int numAnalogFramesPerPeriod,
 					   int numAudioFramesPerPeriod,
-					   float matrixSampleRate, float audioSampleRate,
+					   float analogSampleRate, float audioSampleRate,
 					   void *userData);
 
-void render(int numMatrixFrames, int numAudioFrames, int numMatrixGpioFrames, float *audioIn, float *audioOut,
-			float *matrixIn, float *matrixOut, uint32_t *matrixGpio);
+void render(int numAnalogFrames, int numAudioFrames, int numDigitalFrames, float *audioIn, float *audioOut,
+			float *analogIn, float *analogOut, uint32_t *digital);
 
 void render_medium_prio();
 void render_low_prio();